==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/search/variables_1.js <==
var searchData=
[
  ['a',['a',['../structplplot_1_1__N9.html#ae8a6f4039729e0f6e14795af6b4c2558',1,'plplot::_N9::a()'],['../structplplot_1_1__N10.html#af4b12ee773af19b3cb112f5730fa3826',1,'plplot::_N10::a()'],['../structPLColor.html#a3b4240c54ca0894e627d2b1c794272b1',1,'PLColor::a()'],['../structPLControlPt.html#a73722ef982c3ef58c19c9de1837d7295',1,'PLControlPt::a()'],['../structarc__struct.html#ab54aa54947964a3f511bd81b6004b4fe',1,'arc_struct::a()']]],
  ['abort_5fhandler',['abort_handler',['../plctrl_8c.html#ade4e4af4924b342cc451b9045622bef2',1,'plctrl.c']]],
  ['acc',['acc',['../structPLStrip.html#acfed845c67232fe817b17cc05e22f4e0',1,'PLStrip']]],
  ['active_5fplot',['active_plot',['../structPlPlotter.html#a6d189ffe4f40ce36914934805550bbf4',1,'PlPlotter']]],
  ['active_5fstreams',['active_streams',['../classplstream.html#a40c5a40e609b74ef8b1046da85edf495',1,'plstream']]],
  ['adapter',['adapter',['../aqt_8c.html#a038483d5fc0a9a6512f765134f8f673e',1,'aqt.c']]],
  ['add',['add',['../structplf2ops__t.html#a58119a6cba4ac40f1e31467a8144e279',1,'plf2ops_t']]],
  ['alarm',['alarm',['../structPLStream.html#ae101c904156d069f592ae556c4ae5229',1,'PLStream']]],
  ['alen',['Alen',['../plplotluacLUA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876',1,'plplot']]],
  ['already_5fwarned',['already_warned',['../cairo_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;cairo.c'],['../qt_8cpp.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;qt.cpp'],['../svg_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;svg.c']]],
  ['alt_5fhue_5fpath',['alt_hue_path',['../structplplot_1_1__N10.html#a0ce401d3c749e8ae33652a565a59a5a8',1,'plplot::_N10::alt_hue_path()'],['../structPLControlPt.html#ac2decdd07fee85171291fa766a92f236',1,'PLControlPt::alt_hue_path()']]],
  ['alt_5funicode',['alt_unicode',['../structPLStream.html#ad5b11c7d0725f7b465356a1230111389',1,'PLStream']]],
  ['always_5fstatic',['always_static',['../classoctave__swig__type.html#af01414750456e4ce55fd24643508fddf',1,'octave_swig_type']]],
  ['angle1',['angle1',['../structarc__struct.html#ab5835c9f068a76419d1a35396ed575d3',1,'arc_struct']]],
  ['angle2',['angle2',['../structarc__struct.html#a239e57f45d87b43b53584fff68d9d995',1,'arc_struct']]],
  ['appcounter',['appCounter',['../qt_8cpp.html#ac07b45044ec40360f7ccf5d721906c19',1,'qt.cpp']]],
  ['aqt_5ffont_5fenv_5fnames',['aqt_font_env_names',['../aqt_8c.html#ac9e0702fe235f0af1382c7fbaa0bdb09',1,'aqt.c']]],
  ['aqt_5ffontlookup',['AQT_FontLookup',['../aqt_8c.html#a6fb8ee7352b3d90ad5863a6aa109a3cd',1,'aqt.c']]],
  ['argc',['argc',['../qt_8cpp.html#ad1447518f4372828b8435ae82e48499e',1,'qt.cpp']]],
  ['argtable',['argTable',['../plserver_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;plserver.c'],['../tkMain_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;tkMain.c']]],
  ['argv',['argv',['../qt_8cpp.html#af2efa898e9eed6fe6715279cb1ec35b0',1,'qt.cpp']]],
  ['arpool',['arpool',['../aqt_8c.html#a62288d128ffc307d0f661546ec48d199',1,'aqt.c']]],
  ['arrow_5ffill',['arrow_fill',['../structPLStream.html#a7ac1e3c7c8a4bafc756c2eda23a3e294',1,'PLStream']]],
  ['arrow_5fnpts',['arrow_npts',['../structPLStream.html#acdc0f21ca7d4639067884e64a7f56fae',1,'PLStream']]],
  ['arrow_5fx',['arrow_x',['../structPLStream.html#a015dd508317467f440062b7e1bdddb24',1,'PLStream']]],
  ['arrow_5fy',['arrow_y',['../structPLStream.html#ac334ee79d7d35de4e9298bfea47db84c',1,'PLStream']]],
  ['as_5fbuffer',['as_buffer',['../structPyHeapTypeObject.html#a026c64b0a5163ea580e79640ecf209de',1,'PyHeapTypeObject']]],
  ['as_5fmapping',['as_mapping',['../structPyHeapTypeObject.html#a3112d193aea288a92036360bec1ce0a5',1,'PyHeapTypeObject']]],
  ['as_5fnumber',['as_number',['../structPyHeapTypeObject.html#a795de378df40d11321c0dbe463759560',1,'PyHeapTypeObject']]],
  ['as_5fsequence',['as_sequence',['../structPyHeapTypeObject.html#ad553caad5da3a7004aae1b7ac0289f12',1,'PyHeapTypeObject']]],
  ['aspdev',['aspdev',['../structPLStream.html#aa6d6f9587b12cd4133b172a93ae9d8c1',1,'PLStream']]],
  ['aspect',['aspect',['../structPLStream.html#a79d9ed2a822851f28285913cae12b840',1,'PLStream']]],
  ['aspori',['aspori',['../structPLStream.html#a3bc2ac0e93b21ffff11aba5de71571be',1,'PLStream']]],
  ['at_5fbop',['at_bop',['../structPLRDev.html#a47a7b661ad619d752cc6cf95b9b19dba',1,'PLRDev']]],
  ['at_5feop',['at_eop',['../structPLRDev.html#a18b078383daba6f7399d73aa5b2a8433',1,'PLRDev']]],
  ['attributes',['attributes',['../structswig__lua__class.html#a3061adc91d7cb1a16967927e8d4a7261',1,'swig_lua_class']]],
  ['auto_5fpath',['auto_path',['../structPLStream.html#ad2ba4001e1e8e82da00e8c6011e2bafd',1,'PLStream::auto_path()'],['../plserver_8c.html#a584c59afcabcf1d096319dbc948c4a68',1,'auto_path():&#160;plserver.c']]]
];

==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/search/variables_1.js <==
var searchData=
[
  ['a',['a',['../structplplot_1_1__N9.html#ae8a6f4039729e0f6e14795af6b4c2558',1,'plplot::_N9::a()'],['../structplplot_1_1__N10.html#af4b12ee773af19b3cb112f5730fa3826',1,'plplot::_N10::a()'],['../structPLColor.html#a3b4240c54ca0894e627d2b1c794272b1',1,'PLColor::a()'],['../structPLControlPt.html#a73722ef982c3ef58c19c9de1837d7295',1,'PLControlPt::a()'],['../structarc__struct.html#ab54aa54947964a3f511bd81b6004b4fe',1,'arc_struct::a()']]],
  ['abort_5fhandler',['abort_handler',['../plctrl_8c.html#ade4e4af4924b342cc451b9045622bef2',1,'plctrl.c']]],
  ['acc',['acc',['../structPLStrip.html#acfed845c67232fe817b17cc05e22f4e0',1,'PLStrip']]],
  ['active_5fplot',['active_plot',['../structPlPlotter.html#a6d189ffe4f40ce36914934805550bbf4',1,'PlPlotter']]],
  ['active_5fstreams',['active_streams',['../classplstream.html#a40c5a40e609b74ef8b1046da85edf495',1,'plstream']]],
  ['adapter',['adapter',['../aqt_8c.html#a038483d5fc0a9a6512f765134f8f673e',1,'aqt.c']]],
  ['add',['add',['../structplf2ops__t.html#a3044489613ce51fb127a470667d7a7c0',1,'plf2ops_t']]],
  ['alarm',['alarm',['../structPLStream.html#ae101c904156d069f592ae556c4ae5229',1,'PLStream']]],
  ['alen',['Alen',['../plplotluacLUA__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a27d25ac7e864031d461a8a5460144223',1,'Alen():&#160;plplotcPYTHON_wrap.c']]],
  ['alloc2dgrid',['Alloc2dGrid',['../classplplot.html#ae7e2909e2bcc51a61a0c0259ec330876',1,'plplot']]],
  ['already_5fwarned',['already_warned',['../cairo_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;cairo.c'],['../qt_8cpp.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;qt.cpp'],['../svg_8c.html#a95c7017567d9ecc63d7653e1a1e2778a',1,'already_warned():&#160;svg.c']]],
  ['alt_5fhue_5fpath',['alt_hue_path',['../structplplot_1_1__N10.html#a0ce401d3c749e8ae33652a565a59a5a8',1,'plplot::_N10::alt_hue_path()'],['../structPLControlPt.html#ac2decdd07fee85171291fa766a92f236',1,'PLControlPt::alt_hue_path()']]],
  ['alt_5funicode',['alt_unicode',['../structPLStream.html#ad5b11c7d0725f7b465356a1230111389',1,'PLStream']]],
  ['always_5fstatic',['always_static',['../classoctave__swig__type.html#af01414750456e4ce55fd24643508fddf',1,'octave_swig_type']]],
  ['angle1',['angle1',['../structarc__struct.html#ab5835c9f068a76419d1a35396ed575d3',1,'arc_struct']]],
  ['angle2',['angle2',['../structarc__struct.html#a239e57f45d87b43b53584fff68d9d995',1,'arc_struct']]],
  ['appcounter',['appCounter',['../qt_8cpp.html#ac07b45044ec40360f7ccf5d721906c19',1,'qt.cpp']]],
  ['aqt_5ffont_5fenv_5fnames',['aqt_font_env_names',['../aqt_8c.html#ac9e0702fe235f0af1382c7fbaa0bdb09',1,'aqt.c']]],
  ['aqt_5ffontlookup',['AQT_FontLookup',['../aqt_8c.html#a6fb8ee7352b3d90ad5863a6aa109a3cd',1,'aqt.c']]],
  ['argc',['argc',['../qt_8cpp.html#ad1447518f4372828b8435ae82e48499e',1,'qt.cpp']]],
  ['argtable',['argTable',['../plserver_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;plserver.c'],['../tkMain_8c.html#aa2d7de8127fc5e1205be8243215a5aef',1,'argTable():&#160;tkMain.c']]],
  ['argv',['argv',['../qt_8cpp.html#af2efa898e9eed6fe6715279cb1ec35b0',1,'qt.cpp']]],
  ['arpool',['arpool',['../aqt_8c.html#a62288d128ffc307d0f661546ec48d199',1,'aqt.c']]],
  ['arrow_5ffill',['arrow_fill',['../structPLStream.html#a7ac1e3c7c8a4bafc756c2eda23a3e294',1,'PLStream']]],
  ['arrow_5fnpts',['arrow_npts',['../structPLStream.html#acdc0f21ca7d4639067884e64a7f56fae',1,'PLStream']]],
  ['arrow_5fx',['arrow_x',['../structPLStream.html#a015dd508317467f440062b7e1bdddb24',1,'PLStream']]],
  ['arrow_5fy',['arrow_y',['../structPLStream.html#ac334ee79d7d35de4e9298bfea47db84c',1,'PLStream']]],
  ['as_5fbuffer',['as_buffer',['../structPyHeapTypeObject.html#a026c64b0a5163ea580e79640ecf209de',1,'PyHeapTypeObject']]],
  ['as_5fmapping',['as_mapping',['../structPyHeapTypeObject.html#a3112d193aea288a92036360bec1ce0a5',1,'PyHeapTypeObject']]],
  ['as_5fnumber',['as_number',['../structPyHeapTypeObject.html#a795de378df40d11321c0dbe463759560',1,'PyHeapTypeObject']]],
  ['as_5fsequence',['as_sequence',['../structPyHeapTypeObject.html#ad553caad5da3a7004aae1b7ac0289f12',1,'PyHeapTypeObject']]],
  ['aspdev',['aspdev',['../structPLStream.html#aa6d6f9587b12cd4133b172a93ae9d8c1',1,'PLStream']]],
  ['aspect',['aspect',['../structPLStream.html#a79d9ed2a822851f28285913cae12b840',1,'PLStream']]],
  ['aspori',['aspori',['../structPLStream.html#a3bc2ac0e93b21ffff11aba5de71571be',1,'PLStream']]],
  ['at_5fbop',['at_bop',['../structPLRDev.html#a47a7b661ad619d752cc6cf95b9b19dba',1,'PLRDev']]],
  ['at_5feop',['at_eop',['../structPLRDev.html#a18b078383daba6f7399d73aa5b2a8433',1,'PLRDev']]],
  ['attributes',['attributes',['../structswig__lua__class.html#a3061adc91d7cb1a16967927e8d4a7261',1,'swig_lua_class']]],
  ['auto_5fpath',['auto_path',['../structPLStream.html#ad2ba4001e1e8e82da00e8c6011e2bafd',1,'PLStream::auto_path()'],['../plserver_8c.html#a584c59afcabcf1d096319dbc948c4a68',1,'auto_path():&#160;plserver.c']]]
];
